@@ -1,11 +1,11 @@
 author_info = (("Dmitry Orlov", "me@mosquito.su"),)
 
-package_info = "Asynchronous file IO for Linux Posix and Windows."
+package_info = "Asynchronous file IO for Linux MacOS or Windows."
 package_license = "Apache Software License"
 
 team_email = author_info[0][1]
 
-version_info = (0, 9, 5)
+version_info = (0, 9, 6)
 
 __author__ = ", ".join("{} <{}>".format(*info) for info in author_info)
 __version__ = ".".join(map(str, version_info))
